@@ -57,7 +57,7 @@ class Jinja2Converter(YbeConverter):
 
         out_file = self.get_jinja2_template().render(exam=ybe_exam)
 
-        with open(out_fname, 'w') as f:
+        with open(out_fname, 'w', encoding='utf-8') as f:
             f.write(out_file)
 
         if copy_resources:
@@ -130,7 +130,7 @@ class YbeToLatex(Jinja2Converter):
         Returns:
             jinja2.PackageLoader: the loader for loading the template.
         """
-        return jinja2.PackageLoader('ybe', 'data/latex_templates/default')
+        return jinja2.PackageLoader('ybe', 'data/conversion_templates/latex/default')
 
 
 class YbeToMarkdown(Jinja2Converter):
@@ -156,7 +156,7 @@ class YbeToMarkdown(Jinja2Converter):
         return env
 
     def get_jinja2_template_loader(self):
-        return jinja2.PackageLoader('ybe', 'data/markdown_templates/default')
+        return jinja2.PackageLoader('ybe', 'data/conversion_templates/markdown/default')
 
 
 class YbeToHTML(Jinja2Converter):
@@ -182,7 +182,7 @@ class YbeToHTML(Jinja2Converter):
         return env
 
     def get_jinja2_template_loader(self):
-        return jinja2.PackageLoader('ybe', 'data/html_templates/default')
+        return jinja2.PackageLoader('ybe', 'data/conversion_templates/html/default')
 
 
 class YbeToDocx(YbeConverter):
@@ -234,7 +234,7 @@ class YbeToQTI_v1p2(YbeConverter):
             trim_blocks=True,
             autoescape=True,
             lstrip_blocks=True,
-            loader=jinja2.PackageLoader('ybe', 'data/qti_templates/v1p2'))
+            loader=jinja2.PackageLoader('ybe', 'data/conversion_templates/qti/v1p2'))
 
         env = jinja2.Environment(**default_kwargs)
         env.tests['multiple_choice'] = lambda question: isinstance(question, MultipleChoice)
@@ -242,8 +242,6 @@ class YbeToQTI_v1p2(YbeConverter):
         env.tests['text_only'] = lambda question: isinstance(question, TextOnly)
         env.tests['multiple_response'] = lambda question: isinstance(question, MultipleResponse)
 
-        env.tests['plaintext'] = lambda text: isinstance(text, TextPlain)
-
         env.globals['preprocess_html'] = self._preprocess_html
         env.globals['multiple_choice_question'] = self._convert_multiple_choice
 
@@ -325,7 +323,7 @@ class YbeToQTI_v1p2(YbeConverter):
             'resources': resources.items()
         }
         template = self.jinja2_env.get_template('imsmanifest.xml')
-        with open(os.path.join(dirname, 'imsmanifest.xml'), 'w') as f:
+        with open(os.path.join(dirname, 'imsmanifest.xml'), 'w', encoding='utf-8') as f:
             f.write(template.render(**template_items))
 
     def _write_assessment_meta(self, ybe_exam, dirname, assessment_identifier):
@@ -336,7 +334,7 @@ class YbeToQTI_v1p2(YbeConverter):
             dirname (str): the directory to write the manifest (``imsmanifest.xml``) to.
             assessment_identifier (str): UUID of the assessment
         """
-        if isinstance(ybe_exam.info.description, TextPlain):
+        if ybe_exam.info.description.is_plaintext():
             description = ybe_exam.info.description.to_plaintext()
         else:
             description = self._preprocess_html(ybe_exam.info.description.to_html())
@@ -350,7 +348,7 @@ class YbeToQTI_v1p2(YbeConverter):
             'assignment_group_identifier': uuid.uuid4().hex
         }
         template = self.jinja2_env.get_template('assessment_meta.xml')
-        with open(os.path.join(dirname, assessment_identifier, 'assessment_meta.xml'), 'w') as f:
+        with open(os.path.join(dirname, assessment_identifier, 'assessment_meta.xml'), 'w', encoding='utf-8') as f:
             f.write(template.render(**template_items))
 
     def _write_questions_data(self, ybe_exam, dirname, assessment_identifier):
@@ -374,7 +372,8 @@ class YbeToQTI_v1p2(YbeConverter):
             'converted_questions': [converters[question.__class__](question) for question in ybe_exam.questions]
         }
         template = self.jinja2_env.get_template('assessment.xml')
-        with open(os.path.join(dirname, assessment_identifier, assessment_identifier + '.xml'), 'w') as f:
+        with open(os.path.join(dirname, assessment_identifier,
+                               assessment_identifier + '.xml'), 'w', encoding='utf-8') as f:
             f.write(template.render(**template_items))
 
     def _convert_multiple_choice(self, question):
@@ -387,21 +386,12 @@ class YbeToQTI_v1p2(YbeConverter):
             str: XML string with the question information
         """
         answer_ids = [uuid.uuid4().hex[0:6] for _ in question.answers]
-        feedback_items = self._convert_feedback_items(question.feedback)
-
-        answer_items = []
-        for answer_id, answer in zip(answer_ids, question.answers):
-            answer_items.append((answer_id, answer))
-            if answer.hint:
-                feedback_items.append(self._convert_feedback(f'{answer_id}_fb', answer.hint))
 
         template_items = {
             'question': question,
             'assessment_question_identifierref': uuid.uuid4().hex,
-            'original_answer_ids': ','.join(answer_ids),
-            'answer_items': answer_items,
+            'answer_ids': answer_ids,
             'respconditions': self._create_multiple_choice_respconditions(question, answer_ids),
-            'feedback_items': feedback_items
         }
         template = self.jinja2_env.get_template('multiple_choice_question.xml')
         return template.render(**template_items)
@@ -417,21 +407,12 @@ class YbeToQTI_v1p2(YbeConverter):
             str: XML string with the question information
         """
         answer_ids = [uuid.uuid4().hex[0:6] for _ in question.answers]
-        feedback_items = self._convert_feedback_items(question.feedback)
-
-        answer_items = []
-        for answer_id, answer in zip(answer_ids, question.answers):
-            answer_items.append((answer_id, answer))
-            if answer.hint:
-                feedback_items.append(self._convert_feedback(f'{answer_id}_fb', answer.hint))
 
         template_items = {
             'question': question,
             'assessment_question_identifierref': uuid.uuid4().hex,
-            'original_answer_ids': ','.join(answer_ids),
-            'answer_items': answer_items,
+            'answer_ids': answer_ids,
             'respconditions': self._create_multiple_response_respconditions(question, answer_ids),
-            'feedback_items': feedback_items
         }
         template = self.jinja2_env.get_template('multiple_response_question.xml')
         return template.render(**template_items)
@@ -445,19 +426,9 @@ class YbeToQTI_v1p2(YbeConverter):
         Returns:
             str: XML string with the question information
         """
-        feedback_items = self._convert_feedback_items(question.feedback, allowed_items=['general'])
-
-        respconditions = []
-        if question.feedback.general is not None:
-            respconditions.append(self.jinja2_env.get_template('respcondition_general.xml').render(
-                display_feedback=True))
-        respconditions.append('''<respcondition continue="No"><conditionvar><other/></conditionvar></respcondition>''')
-
         template_items = {
             'question': question,
             'assessment_question_identifierref': uuid.uuid4().hex,
-            'respconditions': respconditions,
-            'feedback_items': feedback_items
         }
         template = self.jinja2_env.get_template('open_question.xml')
         return template.render(**template_items)
@@ -568,42 +539,6 @@ class YbeToQTI_v1p2(YbeConverter):
 
         return respconditions
 
-    def _convert_feedback_items(self, feedback, allowed_items=None):
-        """Convert the feedback items of a question.
-
-        Args:
-            feedback (Feedback): the feedback data
-            allowed_items (list): the list of allowed feedback items
-
-        Returns:
-            List[str]: list with QTI elements for the feedback
-        """
-        allowed_items = allowed_items or ['general', 'on_correct', 'on_incorrect']
-
-        feedback_items = []
-        if feedback.general and 'general' in allowed_items:
-            feedback_items.append(self._convert_feedback('general_fb', feedback.general))
-        if feedback.on_correct and 'on_correct' in allowed_items:
-            feedback_items.append(self._convert_feedback('correct_fb', feedback.on_correct))
-        if feedback.on_incorrect and 'on_incorrect' in allowed_items:
-            feedback_items.append(self._convert_feedback('general_incorrect_fb', feedback.on_incorrect))
-
-        return feedback_items
-
-    def _convert_feedback(self, feedback_id, text):
-        """Convert the feedback items of the provided question into QTI format.
-
-        This will convert the general feedback
-
-        Args:
-            feedback_id (str): the id of the feedback
-            text (TextData): the data element containing the text to write
-
-        Returns:
-            str: XML string with the question information
-        """
-        return self.jinja2_env.get_template('itemfeedback.xml').render(feedback_id=feedback_id, text=text)
-
     @staticmethod
     def format_canvas_equations(text):
         if not text:
