@@ -144,12 +144,12 @@ class Question(YbeExamElement):
 
 @dataclass
 class MultipleChoice(Question):
-    answers: List[MultipleChoiceAnswer] = field(default_factory=list)
+    answers: List[AnswerOption] = field(default_factory=list)
 
 
 @dataclass
 class MultipleResponse(Question):
-    answers: List[MultipleResponseAnswer] = field(default_factory=list)
+    answers: List[AnswerOption] = field(default_factory=list)
 
 
 @dataclass
@@ -158,19 +158,12 @@ class OpenQuestion(Question):
 
 
 @dataclass
-class TextOnly(YbeExamElement):
+class TextOnly(Question):
     pass
 
 
 @dataclass
-class MultipleChoiceAnswer(SimpleYbeNode):
-    text: TextData = field(default_factory=lambda: TextPlain(''))
-    correct: bool = False
-    hint: TextData = None
-
-
-@dataclass
-class MultipleResponseAnswer(SimpleYbeNode):
+class AnswerOption(SimpleYbeNode):
     text: TextData = field(default_factory=lambda: TextPlain(''))
     correct: bool = False
     hint: TextData = None
@@ -179,7 +172,7 @@ class MultipleResponseAnswer(SimpleYbeNode):
 @dataclass
 class QuestionMetaData(SimpleYbeNode):
     general: GeneralQuestionMetaData = field(default_factory=lambda: GeneralQuestionMetaData())
-    analytics: AnalyticsQuestionMetaData = field(default_factory=lambda: AnalyticsQuestionMetaData())
+    analytics: List[AnalyticsQuestionUsage] = field(default_factory=list)
 
 
 @dataclass
@@ -210,9 +203,19 @@ class GeneralQuestionMetaData(SimpleYbeNode):
 
 
 @dataclass
-class AnalyticsQuestionMetaData(SimpleYbeNode):
-    """Analytics about this question, e.g. usage statistics."""
-    analytics: List[dict] = field(default_factory=list)
+class AnalyticsQuestionUsage(SimpleYbeNode):
+    """Represents the usage of this question"""
+
+
+@dataclass
+class QuestionUsedInExam(AnalyticsQuestionUsage):
+    """Represents the usage of this question in an exam.
+
+    This is loaded using the keyword ``exam``.
+    """
+    name: str = None
+    participants: int = None
+    nmr_correct: int = None
 
 
 @dataclass
